import axios from 'axios';
import homeServices from './productsApi';

jest.mock('axios');

describe('homeServices.getProducts', () => {
  afterEach(() => {
    jest.clearAllMocks();
  });

  test('should return data on successful API call', async () => {
    const mockData = { products: [{ id: 1, name: 'Product 1' }] };
    (axios.get as jest.Mock).mockResolvedValue({ data: mockData });

    const result = await homeServices.getProducts();

    expect(result).toEqual(mockData);
    expect(axios.get).toHaveBeenCalledWith('https://dummyjson.com/products');
  });

  test('should throw generic error message on non-Axios error', async () => {
    (axios.get as jest.Mock).mockRejectedValue(new Error('Non-Axios error'));

    await expect(homeServices.getProducts()).rejects.toThrow(
      'Something went wrong. Please try again.'
    );
    expect(axios.get).toHaveBeenCalledWith('https://dummyjson.com/products');
  });
});
